import 'package:flutter/material.dart';
import '../components/text_bold.dart';
import '../constants.dart';
import '../services/auth/auth_service.dart';
import 'user_data_page.dart';

class WelcomePage extends StatelessWidget {
  const WelcomePage({super.key});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('Welcome to ${Constants.appTitle}'),),
      body: SafeArea(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: SingleChildScrollView(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const TextBold(
                  text: 'Connect with Potential Co-Founders Here',
                  fontSize: 24,
                ),
                const SizedBox(height: 16),
                const Text(
                  'The goal of this app is to help you find the ideal co-founder for your startup. '
                  'It aims to connect people with similar goals, complementary '
                  'skills, and shared interests to create successful partnerships.',
                  style: TextStyle(fontSize: 16),
                ),
                const SizedBox(height: 16),
                const Text(
                  'To achieve this and get the most out of the app, '
                  'you will be asked to share some information about yourself '
                  'in the next steps. This includes the following details:\n'
                  '\u25CF Personal Information: Your name, year of birth, and spoken languages will help match you with others.\n'
                  '\u25CF Your Location: To suggest and find co-founders near you.\n'
                  '\u25CF Your Skills and Experiences: To find the ideal co-founder with complementary skills.\n'
                  '\u25CF Your Goals and Interests: To ensure you share a similar vision.\n',
                  style: TextStyle(fontSize: 16),
                ),
                const SizedBox(height: 24),
                Center(
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      ElevatedButton.icon(
                        onPressed: () {
                          AuthService().signOut();
                        },
                        label: const Text('Sign out'),
                        icon: const Icon(Icons.logout),
                      ),
                      const SizedBox(
                        width: 16,
                      ),
                      ElevatedButton.icon(
                        onPressed: () {
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                              builder: (BuildContext context) =>
                                  const UserDataPage(
                                isRegProcess: true,
                                isEditMode: false,
                              ),
                            ),
                          );
                        },
                        label: const Text('Continue'),
                        icon: const Icon(Icons.navigate_next),
                        iconAlignment: IconAlignment.start,
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
